#ifndef STATUSBAR_MENU_H
#define STATUSBAR_MENU_H

#include "Menu.h"

class StatusBarMenu : public Menu
{
    MENU_SINGLETON(StatusBar);

  public:
    void eventShow();
    void eventHide();

    void update();

  protected:

    void updateMessage();
    void updateScore();
    void updateLifes();
    void updateBonus();
    void updateFuel();

    std::string m_message;
    unsigned m_score;
    unsigned m_lifes;
    unsigned m_lastBonusValue;
    unsigned m_lastFuelValue;
};

#endif // STATUSBAR_MENU_H
